#
# spec file for package kakasi
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kakasi
Version:        2.3.6
Release:        5.2
Summary:        Filter to Convert Kanji Characters to Hiragana, Katakana, or Romaji
License:        GPL-2.0-or-later
Group:          Productivity/Text/Convertors
URL:            http://kakasi.namazu.org/
Source:         http://kakasi.namazu.org/stable/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM marguerite@opensuse.org
Patch0:         kakasi-2.3.6-no-return-in-nonvoid-function.patch
BuildRequires:  automake
Requires:       kakasi-dict = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
KAKASI is the language processing filter to convert Kanji characters to
Hiragana, Katakana, or Romaji(1) and may be helpful for reading
Japanese documents. The word-splitting patch is merged from version
2.3.0.

The name "KAKASI" is the abbreviation of "kanji kana simple inverter"
and the inverse of SKK "simple kana kanji converter" developed by
Masahiko Sato at Tohoku University. Most entries of the kakasi
dictionary are derived from the SKK dictionaries. If interested  in the
naming of KAKASI, consult a Japanese-English dictionary.

(1) "Romaji" is an alphabetical description of Japanese pronunciation.

%package devel
Summary:        Header file and libraries of KAKASI
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Provides:       kakaside = %{version}
Obsoletes:      kakaside < %{version}

%description devel
header file and libraries of KAKASI

%package dict
Summary:        The base dictionary of KAKASI
Group:          Productivity/Text/Convertors
Provides:       kakasidi = %{version}
Obsoletes:      kakasidi < %{version}

%description dict
The base dictionary of KAKASI

%prep
%autosetup -p1

# w: version-control-internal-file
rm -rf doc/CVS
# non-linux-readme
rm -rf doc/README.*OS*

%build
cp %{_datadir}/automake*/config.{guess,sub} .
%configure --disable-static --with-pic
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS ONEWS README* THANKS TODO ChangeLog
%doc ./doc/*
%{_bindir}/atoc_conv
%{_bindir}/kakasi
%{_bindir}/kakasi-config
%{_bindir}/mkkanwa
%{_bindir}/rdic_conv
%{_bindir}/wx2_conv
%{_libdir}/libkakasi.so.2
%{_libdir}/libkakasi.so.2.1.0
%dir %{_datadir}/kakasi
%{_datadir}/kakasi/itaijidict
%{_mandir}/man1/kakasi.1.gz
%{_mandir}/man1/kakasi-config.1.gz

%files devel
%defattr(-,root,root)
%{_includedir}/libkakasi.h
%{_libdir}/libkakasi.so

%files dict
%defattr(-,root,root)
%{_datadir}/kakasi/kanwadict

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Sun Jul 27 2014 i@marguerite.su
- update version 2.3.6
  * see NEWS if you know Japanese
- drop bugzilla-154848-array-subscript-out-of-range.patch
  * upstream fixed
- drop kakasi-2.3.4-fclose.patch
  * upstream fixed
- add kakasi-2.3.6-no-return-in-nonvoid-function.patch
* Wed May 30 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Source config.guess using a more future-proof location wildcard
* Thu Mar 22 2012 dvaleev@suse.com
- fix ppc64 build
* Fri Aug 14 2009 ro@suse.de
- add some missing fclose calls to atoc-conv,rdic-conf and wx2-conv
  (bnc#526753)
* Thu Jan  8 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Thu Mar  9 2006 mfabian@suse.de
- Bugzilla #154848: "array subscript out of range".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 11 2004 adrian@suse.de
- add %%run_ldconfig
* Sat Aug 10 2002 mfabian@suse.de
- kakasi-devel should require kakasi
* Mon Apr  8 2002 mfabian@suse.de
- use %%{_libdir}
- add /usr/share/kakasi/ to file list
- fix buildrooting
* Fri Nov  2 2001 mfabian@suse.de
- rename subpackages:
  kakaside -> kakasi-devel
  kakasidi -> kakasi-dict
- add Requires: kakasi-dict to main package
- export CFLAGS
* Wed Oct 10 2001 mfabian@suse.de
- update to kakasi-2.3.4 (several small bugfixes, for details
  see the NEW file)
* Fri Aug 10 2001 mfabian@suse.de
- update to kakasi-2.3.3 (bugfix release)
- move .so symbolic link in development sub-package
- remove ldconfig from post and postun scripts
- some .spec file cleanup
* Mon May  7 2001 mfabian@suse.de
- bzip2 source
* Wed Jul 12 2000 mfabian@suse.de
- new package: kakasi-2.3.2
  (used the srpm on the kakasi website http://kakasi.namazu.org/
  as a starting point)
